/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.so;

import java.util.Properties;

import org.ow2.petals.jmx.api.api.monitoring.Defect;

/**
 * <p>
 * A mapper to transform:
 * <ul>
 * <li>{@link Defect} emitter into a Nagios host,</li>
 * <li>and a defect name into a Nagios service.</li>
 * </ul>
 * </p>
 * <p>
 * Mapping rules are defined through properties as following:
 * <pre>
 * {@code}
 * emitter.&lt;defect_emitter&gt; = &lt;nagios_host&gt;
 * name.&lt;defect_name&gt; = &lt;nagios_service&gt;
 * {@code}
 * </pre>
 * 
 * </p>
 * 
 * @author Christophe DENEUX - Liangora
 * 
 */
public class NagiosMapper {

    /**
     * Prefix of the property name of a defect emitter
     */
    public final static String EMITTER_PREFIX = "emitter.";

    /**
     * Prefix of the property name of a defect name
     */
    public final static String NAME_PREFIX = "name.";

    /**
     * The mapping rules
     */
    private final Properties mappingRules;

    public NagiosMapper(final Properties mappingRules) {
        this.mappingRules = mappingRules;
    }

    /**
     * Get the Nagios host associated to the given defect emitter
     * 
     * @param defectEmitter
     *            The defect emitter to transform into a Nagios host.
     * @return The Nagios host associated to the given defect emitter, or the
     *         defect emitter if no mapping is found.
     */
    public String getNagiosHost(final String defectEmitter) {
        if (this.mappingRules != null) {
            return this.mappingRules.getProperty(EMITTER_PREFIX + defectEmitter, defectEmitter);
        } else {
            return defectEmitter;
        }
    }

    /**
     * Get the Nagios service associated to the given defect name
     * 
     * @param defectName
     *            The defect name to transform into a Nagios service.
     * @return The Nagios service associated to the given defect name, or the
     *         defect name if no mapping is found.
     */
    public String getNagiosService(final String defectName) {
        if (this.mappingRules != null) {
            return this.mappingRules.getProperty(NAME_PREFIX + defectName, defectName);
        } else {
            return defectName;
        }
    }

}
